@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -44,7 +44,9 @@ int css(FILE *fp_css)
    }
 
    fputs("<style>\n",fp_ou);
-   fputs(".logo {font-family:Verdana,Tahoma,Arial;font-size:11px;color:#006699;}\n",fp_ou);
+
+   sprintf(csstext,".logo {font-family:Verdana,Tahoma,Arial;font-size:11px;color:%s;}\n",LogoTextColor);
+   fputs(csstext,fp_ou);
    sprintf(csstext,".body {font-family:%s;color:%s;background-color:%s;}\n", \
 		FontFace, TxColor, BgColor);
    fputs(csstext,fp_ou);
