@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -92,8 +92,11 @@ void download_report()
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
 
    if(strlen(LogoImage) > 0) {
-      sprintf(url,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
+      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
       fputs(url,fp_ou);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
+      fputs("</table>\n",fp_ou);
    }
 
    show_sarg(fp_ou, "..");
@@ -157,14 +160,19 @@ void download_report()
          } else strcpy(name,user);
       } else strcpy(name,user);
 
-      if(DeniedReportLimit) {
+      if(dotinuser && strstr(name,"_")) {
+         str2=(char *)subs(name,"_",".");
+         strcpy(name,str2);
+      }
+
+      if(DownloadReportLimit) {
          if(strcmp(ouser2,name) == 0) {
             count++; 
          } else {
             count=1;
             strcpy(ouser2,name);
          }
-         if(count >= DeniedReportLimit)
+         if(count >= DownloadReportLimit)
             continue;
       }
 
