@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -645,6 +645,12 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"download_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         DownloadReportLimit=atoi(buf);
+         return;
+      }
+
       if(strstr(buf,"www_document_root") != 0) {
          getword(wbuf,buf,' ');
          strcpy(wwwDocumentRoot,buf);
