@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -39,7 +39,7 @@ void htmlrel()
    char periodo[MAXLEN], usuario[MAXLEN], wusuario[MAXLEN], u2[MAXLEN], duser[MAXLEN];
    char userbytes[20], userelap[20], userurl[1024], userhora[9], userdia[9];
    char user_ip[MAXLEN], olduserip[MAXLEN], tmp2[MAXLEN], tmp3[MAXLEN], incac[20], oucac[20];
-   char denied_report[255];
+   char denied_report[255], name2[MAXLEN];
    char ttd1[3], ttd2[3], ttd3[5], ttt1[3], ttt2[3], ttt3[3];
    char *str;
    char ftime[128], warea[MAXLEN];
@@ -187,12 +187,13 @@ void htmlrel()
            background-image:url(%s)\">\n",FontFace,TitleFontSize,BgColor,BgImage);
       fputs(buf,fp_ou);
 
-      if(strlen(LogoImage) > 0) {
-         fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-         sprintf(html,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
-         fputs(html,fp_ou);
-         fputs("</table>\n",fp_ou);
-      }
+   if(strlen(LogoImage) > 0) {
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
+      sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
+      fputs(html,fp_ou);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
+      fputs("</table>\n",fp_ou);
+   }
 
       show_sarg(fp_ou,"../..");
       fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
@@ -220,10 +221,16 @@ void htmlrel()
             }
          } else strcpy(name,u2);
       } else strcpy(name,u2);
+
+      strcpy(name2,name);
+      if(dotinuser && strstr(name2,"_")) {
+         str2=(char *)subs(name2,"_",".");
+         strcpy(name2,str2);
+      }
    
       sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],periodo);
       fputs(html,fp_ou);
-      sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name);
+      sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name2);
       fputs(html,fp_ou);
       sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s, %s</td></tr>\n",text[104],UserSortField,UserSortOrder);
       fputs(html,fp_ou);
@@ -437,7 +444,7 @@ void htmlrel()
             fclose(fp_ip);
             fclose(fp_ip2);
 
-            sprintf(csort,"sort -n -T %s -k 1,1 -k 5,5 -o %s %s",TempDir,tmp3,tmp2);
+            sprintf(csort,"sort -n -T %s -k 1,1 -k 5,5 -o '%s' '%s'",TempDir,tmp3,tmp2);
             system(csort);
    
             if ((fp_ip = fopen(tmp3, "r")) == 0) {
