@@ -288,17 +288,13 @@ int  debugz;
 int  debugm;
 int  AuthfailReportLimit;
 int  DeniedReportLimit;
+int  DownloadReportLimit;
 int  SiteUsersReportLimit;
 int  DansGuardianReportLimit;
 int  SquidGuardReportLimit;
 int  UserReportLimit;
 int  download_flag;
-int  AuthfailReportLimit;
-int  DeniedReportLimit;
-int  SiteUsersReportLimit;
-int  SquidGuardReportLimit;
-int  UserReportLimit;
-int  download_flag;
+int  dotinuser;
 long l1, l2;
 float perc;
 
