@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -67,7 +67,7 @@ void mklastlog()
    (void)closedir( dirp );
    fclose(fp_ou);
    
-   sprintf(buf,"sort -n -k 1,1 -o %slastlog %s",outdir,temp);
+   sprintf(buf,"sort -n -k 1,1 -o '%slastlog' '%s'",outdir,temp);
    system(buf);
 
    unlink(temp);
