@@ -1,10 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso		             orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator	           http://sarg-squid.org
- * 
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
+ *
  * SARG donations:
- *      please look at http://sarg.sourceforge.net/donations.php 
+ *      please look at http://sarg.sourceforge.net/donations.php
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -159,6 +159,7 @@ int main(argc,argv)
    strcpy(LogoTextColor,"#000000");
    strcpy(HeaderColor,"darkblue");
    strcpy(HeaderBgColor,"#DDDDDD");
+   strcpy(LogoTextColor,"#006699");
    strcpy(FontSize,"9px");
    strcpy(TempDir,"/tmp");
    strcpy(OutputDir,"/usr/local/etc/httpd/htdocs/squid-reports");
@@ -248,6 +249,7 @@ int main(argc,argv)
    AuthfailReportLimit=10;
    DansGuardianReportLimit=10;
    SquidGuardReportLimit=10;
+   DownloadReportLimit=50;
    UserReportLimit=0;
    debug=0;
    debugz=0;
@@ -865,8 +867,8 @@ int main(argc,argv)
               if((str=(char *) strstr(str+1, ".")) != (char *) NULL ) {
                  strcpy(ip,data);
        	         strcpy(elap,"0");
-	         getword(user,bufz,' ');
 	         getword(none,bufz,' ');
+	         getword(user,bufz,' ');
 	         getword(data,bufz,']');
 	         getword(fun,bufz,'"');
 	         getword(fun,bufz,' ');
@@ -891,8 +893,10 @@ int main(argc,argv)
 
 	   if(!common) {
 	      getword(elap,bufz,' ');
-	      while(strcmp(elap,"") == 0)
+              bzero(elap, 255);
+	      while(strcmp(elap,"") == 0 && strlen(bufz) > 0)
 	         getword(elap,bufz,' ');
+              if(strlen(elap) < 1) continue;
 	      getword(ip,bufz,' ');
 	      getword(code,bufz,' ');
 	      getword(tam,bufz,' ');
@@ -979,9 +983,11 @@ int main(argc,argv)
            sprintf(user,"%s.%s",w,wuser);
         }
 
+        dotinuser=0;
 	str=user;
 	for(z1=0; z1<strlen(str); z1++) {
 	   if(isalnum(str[z1]) || ispunct(str[z1])) {
+	   if(str[z1]=='.') dotinuser++;
 	   if(str[z1]=='?' || str[z1]=='.' || str[z1]==':' || str[z1]=='/' || str[z1]=='\\')
 	      str[z1]='_';
 	   }
@@ -991,6 +997,8 @@ int main(argc,argv)
         if(strncmp(NtlmUserFormat,"user",4) == 0) {
            if(strstr(user,"_") != 0)
               getword(warea,user,'_');  
+           if(strstr(user,"+") != 0)
+              getword(warea,user,'+');  
         }
 
         if(strstr(ReportType,"denied") != 0)
@@ -1076,8 +1084,8 @@ int main(argc,argv)
 	         l=1;else l=0;
  	   }
            if(fhost) {
-              l=vhexclude(excludefile,ip);
-              if(l) l=vhexclude(excludefile,url);
+//              l=vhexclude(excludefile,ip);
+              l=vhexclude(excludefile,url);
               if(!l)
 	         totregsx++;
            }
@@ -1373,7 +1381,7 @@ int main(argc,argv)
    sort_users_log(tmp, debug);
 
    if(strstr(ReportType,"denied") != 0) {
-      sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o %s %s",tmp,tmp5,tmp4);
+      sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o '%s' '%s'",tmp,tmp5,tmp4);
       system(csort);
       unlink(tmp4);
    }
