@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -236,8 +236,11 @@ void gerarel()
             fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_tt);
 
             if(strlen(LogoImage) > 0) {
-               sprintf(html,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+               fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_tt);
+               sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
                fputs(html,fp_tt);
+               fputs("<tr><td height=\"5\"></td></tr>\n",fp_tt);
+               fputs("</table>\n",fp_tt);
             }
 
 	    show_sarg(fp_tt, "../..");
@@ -262,6 +265,11 @@ void gerarel()
                } else strcpy(name,u2);
             } else strcpy(name,u2);
 
+            if(dotinuser && strstr(name,"_")) {
+               str2=(char *)subs(name,"_",".");
+               strcpy(name,str2);
+            }
+
             sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],periodo);
             fputs(html,fp_tt);
             sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name);
