@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -72,7 +72,7 @@ void topsites()
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -k 4,4 -o %s %s",geral2,geral);
+   sprintf(csort,"sort -k 4,4 -o '%s' '%s'",geral2,geral);
    system(csort);
 
    if((fp_in=fopen(geral2,"r"))==NULL) {
@@ -145,7 +145,7 @@ void topsites()
    if(strcmp(TopsitesSortType,"d") == 0)
       strcpy(sortt,"-r");
 
-   sprintf(csort,"sort %s -k %s -o %s %s",sortt,sortf,sites,geral3);
+   sprintf(csort,"sort %s -k %s -o '%s' '%s'",sortt,sortf,sites,geral3);
    system(csort);
 
    unlink(geral2);
@@ -177,8 +177,9 @@ void topsites()
 
    if(strlen(LogoImage) > 0) {
       fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(url,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
       fputs(url,fp_ou);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
       fputs("</table>\n",fp_ou);
    }
 
