@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -42,7 +42,7 @@ int topuser()
    char ip[MAXLEN], hora[9], data[11], elap[15], incac[15], oucac[15], html[MAXLEN];
    char ipantes[MAXLEN], nameantes[MAXLEN];
    char sfield[10]="2,2";
-   char order[3]="-r";
+   char order[255]="-r";
    char wheader[512];
    char ftime[128];
    int  totuser=0;
@@ -172,7 +172,7 @@ int topuser()
    if(strcmp(TopuserSortOrder,"normal") == 0)
       order[0]='\0';
 
-   sprintf(csort,"sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
+   sprintf(csort,"sort -n -T %s %s -k %s -o '%s' '%s'", TempDir, order, sfield, top1, top2);
    system(csort);
 
    unlink(top2);
@@ -224,8 +224,9 @@ int topuser()
 
    if(strlen(LogoImage) > 0) {
       fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
-      sprintf(preg,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font></th></tr>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      sprintf(preg,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
       fputs(preg,fp_top3);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_top3);
       fputs("</table>\n",fp_top3);
    }
 
@@ -530,6 +531,11 @@ int topuser()
       if(strstr(ReportType,"users_sites") == 0)
          href[0]='\0';
 
+      if(dotinuser && strstr(name,"_")) {
+         str2=(char *)subs(name,"_",".");
+         strcpy(name,str2);
+      }
+
       sprintf(preg,"<tr><td %s>%s</td><td %s>%s</td><td %s>%s%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s<td %s>%s</td></tr>\n",hbc1,val1,hbc2,val2,hbc2,href,name,hbc3,wwork1,hbc4,wwork2,hbc5,val3,hbc6,val4,hbc7,val5,hbc8,val6,hbc9,wwork3,hbc10,val7);
 
       if(strstr(user,"TOTAL") != 0) {
