@@ -1,7 +1,7 @@
 /*
- * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
  *                                                            1998, 2005
- * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
  *      please look at http://sarg.sourceforge.net/donations.php
@@ -118,7 +118,7 @@ void useragent()
       debuga(msg);
    }
 
-   sprintf(csort,"sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o %s %s",tmp2,tmp);
+   sprintf(csort,"sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o '%s' '%s'",tmp2,tmp);
    system(csort);
 
    unlink(tmp);
@@ -152,11 +152,11 @@ void useragent()
    sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs(html,fp_ht);
 
-
    if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ht);
-      sprintf(html,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ht);
+      sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
       fputs(html,fp_ht);
+      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ht);
       fputs("</table>\n",fp_ht);
    }
 
@@ -213,7 +213,7 @@ void useragent()
    fclose(fp_in);
    fclose(fp_ou);
 
-   sprintf(csort,"sort -n -t '\\' -k 3,3 -o %s %s",tmp,tmp2);
+   sprintf(csort,"sort -n -t '\\' -k 3,3 -o '%s' '%s'",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
@@ -261,7 +261,7 @@ void useragent()
 
    unlink(tmp);
 
-   sprintf(csort,"sort -n -r -k 1,1 -o %s %s",tmp,tmp2);
+   sprintf(csort,"sort -n -r -k 1,1 -o '%s' '%s'",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
